@@ -84,7 +84,7 @@ def predict_detail(input: List[str]) -> List[str]:
         result = f'Input text: "{text}"\nProbability:\n'
         for lang_name, prob in prob_details:
             result += f'\t{lang_name}: {prob:.4f}\n'
-        result += f'Our language model identified that the input text is "{max_lang_name.upper()}", with a confidence level of {max_prob * 100:.2f}%.\n\n'
+        result += f'Thus, the input text is "{max_lang_name.upper()}", with a confidence level of {max_prob * 100:.2f}%.\n\n'
 
         results.append(result)
 
